@@ -1,10 +1,7 @@
-`depth.RP` <- function(data, trim, nproj = 50, xeps = 0.0000001, x = NULL){
+`depth.RP` <- function(data, trim = 0.25, nproj = 50, xeps = 0.0000001, x = NULL){
   functions = t(data$y)
   n = dim(functions)[1]
   p = dim(functions)[2]
-  if(missing(trim)){
-     trim = 0.25
-  }
   if(is.null(x)) 
      x = 1:p
   prof = rep(0.0,n)
@@ -14,7 +11,7 @@
       z = z/sqrt(modulo)
       valor = functions %*% z
       Fn = ecdf(valor)
-      prof = prof + (Fn(valor) * (1-Fn(valor-xeps)))
+      prof = prof + (Fn(valor) * (1 - Fn(valor - xeps)))
   }
   prof = prof / nproj
   k = which.max(prof)
@@ -23,8 +20,9 @@
   mtrim = matrix(NA, nrow = nl, ncol = dim(functions)[2])
   for(j in 1:length(trim)) {
       lista = which(prof >= quantile(prof, probs = trim[j], na.rm = TRUE))
-      mtrim[j,] = apply(functions[lista,],2,mean)
+      mtrim[j,] = apply(functions[lista,], 2, mean)
   }
-  return(list("median" = med, "lmed" = k, "mtrim" = mtrim, "ltrim" = lista, "prof" = prof))
+  return(list("median" = med, "lmed" = k, "mtrim" = mtrim, 
+         "ltrim" = lista, "prof" = prof))
 }
 
